import { MiddlewareLayoutSelector, MiddlewareSelector, MiddlewareScroller, MiddlewareScaler, MiddlewareRuler, MiddlewareTextEditor, MiddlewareDragger, MiddlewareInfo } from '@idraw/core';
function isValidMode(mode) {
    return ['select', 'drag', 'readOnly'].includes(mode);
}
export function runMiddlewares(core, store) {
    const { enableRuler, enableScale, enableScroll, enableSelect, enableTextEdit, enableDrag, enableInfo } = store.getSnapshot();
    if (enableScroll === true) {
        core.use(MiddlewareScroller);
    }
    else if (enableScroll === false) {
        core.disuse(MiddlewareScroller);
    }
    if (enableSelect === true) {
        core.use(MiddlewareLayoutSelector);
        core.use(MiddlewareSelector);
    }
    else if (enableSelect === false) {
        core.disuse(MiddlewareLayoutSelector);
        core.disuse(MiddlewareSelector);
    }
    if (enableScale === true) {
        core.use(MiddlewareScaler);
    }
    else if (enableScale === false) {
        core.disuse(MiddlewareScaler);
    }
    if (enableRuler === true) {
        core.use(MiddlewareRuler);
    }
    else if (enableRuler === false) {
        core.disuse(MiddlewareRuler);
    }
    if (enableTextEdit === true) {
        core.use(MiddlewareTextEditor);
    }
    else if (enableTextEdit === false) {
        core.disuse(MiddlewareTextEditor);
    }
    if (enableDrag === true) {
        core.use(MiddlewareDragger);
    }
    else if (enableDrag === false) {
        core.disuse(MiddlewareDragger);
    }
    if (enableInfo === true) {
        core.use(MiddlewareInfo);
    }
    else if (enableInfo === false) {
        core.disuse(MiddlewareInfo);
    }
}
export function changeMode(mode, core, store) {
    let enableScale = false;
    let enableScroll = false;
    let enableSelect = false;
    let enableTextEdit = false;
    let enableDrag = false;
    let enableRuler = false;
    const enableInfo = true;
    let innerMode = 'select';
    store.set('mode', innerMode);
    if (isValidMode(mode)) {
        innerMode = mode;
    }
    else {
        console.warn(`${mode} is invalid mode of iDraw.js`);
    }
    if (innerMode === 'select') {
        enableScale = true;
        enableScroll = true;
        enableSelect = true;
        enableTextEdit = true;
        enableDrag = false;
        enableRuler = true;
    }
    else if (innerMode === 'drag') {
        enableScale = true;
        enableScroll = true;
        enableSelect = false;
        enableTextEdit = false;
        enableDrag = true;
        enableRuler = true;
    }
    else if (innerMode === 'readOnly') {
        enableScale = false;
        enableScroll = false;
        enableSelect = false;
        enableTextEdit = false;
        enableDrag = false;
        enableRuler = false;
    }
    store.set('enableScale', enableScale);
    store.set('enableScroll', enableScroll);
    store.set('enableSelect', enableSelect);
    store.set('enableTextEdit', enableTextEdit);
    store.set('enableDrag', enableDrag);
    store.set('enableRuler', enableRuler);
    store.set('enableInfo', enableInfo);
    runMiddlewares(core, store);
}
